***************************************************************
* Calculate 25 HML beta and BM sorted portfolio returns
* Data: CRSP monthly returns and Compustat Merged Industrial Annual Files
* Fama and French 3 factors are from Prof. Ken French's webpage.
*
* @ Xiaoji Lin and Lu Zhang 2012
***************************************************************;

* --------------------------------------------------------------------*
** 1. Load CRSP data;
* --------------------------------------------------------------------*;

libname mylib 'C:\RESEARCH\Macro-Finance\CovCharicteristic\SAS';

%let begyear=1950;
%let endyear=2010;
%let begmon=6;
%let endmon=6;

proc contents data=mylib.CompustatAnnual2011Jan;run;
proc contents data=mylib.crspMay2011;run;

*/First work on CRSP data monthly returns*/
*/keep NYSE, AMEX and NASDQ;
data crsp;
set mylib.crspMay2011;
where (exchcd=1 or exchcd=2 or exchcd=3);
year=year(date);
month=month(date);
run;
proc contents data=crsp;run;
*/ deal with missing values in shares outstanding, exchange code and industry classification code;

  data crsp; set crsp;
   by permno year month;
   where date is not missing;
   i=0;
    do while(i<2);
     lshrout = lag(shrout);
     lexchcd = lag(exchcd);
     lsiccd = lag(siccd);
     
     if permno = lag(permno) and shrout = . then shrout = lshrout;
     if permno = lag(permno) and exchcd = . then exchcd = lexchcd;
     if permno = lag(permno) and siccd = . then siccd = lsiccd;
     
     i+1;
    end;
   if last.month then output;
   drop i lshrout lexchcd lsiccd;
   run;
*/look at the distribution of Delisting Code;

proc univariate data=crsp; var dlstcd;run;
* /look at a single firm for example, CSCO;
proc print data=crsp;
var  date permno ret ticker;
where permno=76076 and year>2001;
run;
*/keep common stock;
	data crsp1;
set crsp;
where (shrcd =10 or shrcd = 11);
id =1; 	** creat a variable 'id' to use later on;
run;

*/ Firms have to have at least 2 years of observations;
proc sql;
	create table id as select permno, sum(id) as n from crsp1 group by permno;
quit;
proc sort data=crsp1; by permno; run;
proc sort data=id; by permno;run;
data crsp11;
	merge id crsp1;
	by permno;
	if n < 24 then delete;
	drop id;run;

*//adjusting delisting bias;
*//replace dlret by ddret;

data crsp2;
SET crsp11;
* Shumway (1997) adjustment for missing delisting codes *;

    if (dlstcd = 500 | dlstcd <= 584 and dlstcd >= 520) & hexcd = 3 & (dlret = .S | dlret = .T | dlret = .P) then Ddlret = -.55;
    else if (dlstcd = 500 | dlstcd <= 584 and dlstcd >= 520) & (hexcd = 1 | hexcd =2 ) & (dlret = .S | dlret = .T | dlret = .P) then Ddlret = -.3;
    else if dlret = .S | dlret = .T | dlret = .A | dlret = .P then Ddlret = .;
	ELSE DDLRET=DLRET;
    delist_date=date; format delist_date yymmddn8.;
     run;

	proc print data=crsp2;
	var PERMNO ticker date ret  dlret ddlret dlstcd;
			where permno=76076 and year>2001;
	run;
	proc sort data=crsp2; by permno date;run;

*/ replace returns with delisting code;
	data crsp_ret;
	set crsp2;
	IF Dlstcd=. or dlstcd=100 THEN ret=rET; ELSE ret=ddlret;run;

	proc print data=crsp_ret;
	var ticker date ret ddlret   dlret;
		*WHERE permno=10019 and yr>1999;
		where permno=76076 and year>2001;
	run;
	proc sort data=crsp_ret nodupkey; by permno date;run;
	proc contents data =crsp_ret;run;

* --------------------------------------------------------------------*
*      make new vars: yyyymm and me				                    *
* --------------------------------------------------------------------*;

  *The reason we make up variable yyyymm is just for convenience of making up portfolios in the following steps;
data crsp_ret; 
 set crsp_ret;
  yyyymm=year*100 + month; 	* create yet another date index called yyyymm, including both year and month information in one variable;
  me = abs(prc)*shrout/1000;    * create market equity variable,  divide by 1000 - in $millions;
  * me in this code is not used directly. It is the market value of equity every month;
  * We need June mkt equity as size;
  * we need Dec mkt equity as bk/mkt ratio;
run;
proc sort;
by permno year month;
run;

* --------------------------------------------------------------------*
* Delete the observations outside of the year and month range                                  *
* --------------------------------------------------------------------*;
data crsp_ret; 
 set crsp_ret;
 if yyyymm ge %eval((&endyear)*100+(&endmon+1)) then delete; 
 if yyyymm le %eval((&begyear)*100+(&begmon-1)) then delete; 
run;
proc sort;
by permno year month;
run;

data crsp_ret1; 
 set crsp_ret;
  If (shrout <= 0) and (shrout ne .)  then delete; * get rid of the cases where shares outstanding is negative or zero;
  * NOte:  here we don't delete the cases where shrout =.;
  If ret = .P  or ret = .B or ret = .T  or ret = .  then delete; * get rid of missing returns;
                 

* --------------------------------------------------------------------*
*  Preparing for merging with compustat annual variables. 
* create a variable called cyear in order to merge with compustat annual data set   
* --------------------------------------------------------------------*;

* create cyear for merging with compustat;
 data crsp_ret_new; set crsp_ret1; * new CRSP data set created, named crsp_ret_new;
 if month eq . then delete;
 if month le %eval(&begmon) then cyear=year-2; * if month<=6, then the annual data should be 2 years ago, so it should be matched with t-2 year compustat data;
 if month ge %eval(&endmon+1) then cyear=year-1; * if month>6, then the annual data should be 1 years ago, so it should be matched with t-1 year compustat data;
run;
  
	proc print data=crsp_ret_new;
	var ticker date yyyymm year month cyear ret;
		*WHERE permno=10019 and yr>1999;
		where permno=76076 and year>2001;
	run;
*Note: crsp_ret_new has the these variables: yyyymm permno year month cyear me prc ret;
*Note: cyear is created only for matching CRSP data with compustat data;
*Note: cyear is useless for other purpose;
proc sort data=crsp_ret_new; 
   by permno cyear; 
run;

***********************************************************
*   work on crsp_ret_new data set to get june_me variable                                   *
***********************************************************;
* june_me is not an annual variable, it is just the firm size;
* Therefore, for CRSP_june_me, the cyear is created differently from the way cyear is created for merging crsp data set and compustat annual data set in the above;
* Note: here, cyear=year-1, instead of cyear=year-2, although month=6; 
data crsp_june_me; set crsp_ret_new; * get the data from the end of step II;
  where month=6;
  cyear=year-1;
  june_me=me;
  if june_me=. then delete;
  if cyear=. then delete;
keep permno cyear june_me exchcd shrcd;
proc sort data=crsp_june_me;by permno cyear;run;

proc contents data=crsp_ret_new;run;

************************************************************
** To get Market value of equity at Dec, to calculate Bk/mkt ratio;
************************************************************;
* Dec_me is not an annual variable, it is just a variable for calculating market to book ratio at the end of year t-1;
* Therefore, for CRSP_Dec_me, the cyear is created differently from the way cyear is created for merging crsp data set and compustat annual data set in the above;
* The cyear is also different from the Cyear in CRSP_JUNE_ME where cyear = year-1;
* Note: here, cyear=year, instead of cyear=year-1 in CRSP_JUNE_ME, because Month=6; 
* Refer to FF 1992 or French Website for details about the formation;
data crsp_Dec_me; set crsp_ret_new; * get the data from the end of step II;
  where month=12;
  cyear=year;
  Dec_me=me;
  if Dec_me=. then delete;
  if cyear=. then delete;
keep permno cyear Dec_me shrcd;
proc sort data=crsp_Dec_me; by permno cyear;run;

*merge crsp_dec_me with crsp_june_me;
data Dec_june_me; merge crsp_june_me (in=in1) crsp_dec_me (in=in2);
by permno cyear;
run;
proc sort data=Dec_june_me; by permno cyear;run;

*merge crsp_new_ret with Dec_june_me to get the market value of equity in Dec and June;
data crsp_DecJune_merged1; merge crsp_ret_new (in=in1) Dec_june_me (in=in2);
by permno cyear;
if in1=1 and in2=1;
	npermno = permno; 								 * /change permno in CRSP to npermno in Compustat to facilitate merging two database;
	keep npermno ret june_me dec_me date cyear year month yyyymm siccd exchcd prc shrcd me;
run;
proc contents data=crsp_DEcJune_merged1;run;
 proc sort data=crsp_DecJune_merged1;by npermno DATE; run; 
*Note:  crsp_new_juneme_merged has these variables: permno ret june_me dec_me date cyear year month yyyymm siccd;

proc expand data=crsp_DecJune_merged1 out=crsp_DecJune_merged method=none;
by npermno;
id DATE;
*	convert ret=lagRet/transformout=(lag 1);
	convert me=lagME/transformout=(lag 1);
run;

* --------------------------------------------------------------------*
** 2. Work on Compustat merged database;
* --------------------------------------------------------------------*;

data compu;
 set mylib.CompustatAnnual2011Jan; */Compustat Annual Merged Data file/;
 	where fyr>0;                                */ only keep the observations with positive fiscal year end month;
 	cyear = fyear ;  							* /create variable cyear( compustat year variable);  	

*** / Missing values;
 	if fyear=. then delete;						*/ delete firm-year obs with missing values;
	npermno=Lpermno;
run;
proc freq data=compu; 	table fyear; 	title 'number of firms in Compustat  per year';	run;
	***// TO get number of firms each year;
Proc contents data = compu; run;
proc sort data=compu nodupkey; by npermno cyear;run;


*/ / Merge CRSP and COMPUSTAT two data sets///;
data crspCompuMerged;
merge crsp_DecJune_merged(in=a) Compu(in=b);
	by npermno cyear;
	if a and b;
run;	
	
data crspCompuMerged1;
set crspCompuMerged;
by NPERMNO;

***/ Book value of equity;
	if TXDB=. or TXDB=.C then extra1=0; else extra1 = TXDB;   */ deferred taxes;
	if ITCB=. or ITCB=.C then extra2=0; else extra2= ITCB; */ investment tax credit;
	if PSTKRV=. or PSTKRV=.C then extra3=0;  else extra3 = PSTKRV;  */redemption; 
	if extra3 = 0 and PSTKL ne . and PSTKL ne .C then extra3 = PSTKL; */liquidation;
 	if extra3 = 0 and PSTK ne . and PSTK ne .C then extra3 = PSTK; */liquidation;
	extra=extra1 + extra2 - extra3;									* / define book value following FF 92;
	if extra <0 or extra = . then extra = 0;
	bv=CEQ+extra;											*/ book value of equity;
	if bv<=0 then delete;									*/ drop obs with negative book values;
	
****//book to market ratio;
	bm=bv/Dec_me;											*/book to market ratio is bk / Market value of equity in Dec;
	if bm=. then delete;
	if 4900<siccd<4999 or 6000<siccd<6999 then delete; 		*/ remove regulated and financial firms following Liu, Whited and Zhang 2010;

run;

*****************************************************************************
** Construct 5 book to market break points;
** bm break points are from NYSE Following FF1993;
******************************************************************************;

* Keep only NYSE stocks;
data crspCompuMergedNYSE;
set crspCompuMerged1;
where (exchcd=1);
proc sort data=crspCompuMergedNYSE; by cyear;run;
* TO get bk/mkt break points of each 5 portfolios;

PROC UNIVARIATE DATA=crspCompuMergedNYSE NOPRINT;
VAR bm;
BY cyear; 
OUTPUT OUT=bmBreakPt PCTLPTS= 20 to 80 by 20  PCTLPRE=bm_rank_; run;

*To merge the original data with bm ranks;
proc sort data=crspCompuMerged1; by cyear;

DATA crspCompuMergedNew; MERGE crspCompuMerged1 (in=in1) bmBreakPt (in=in2); BY cyear; 
if in1=1 and in2=1; * we don't add more observations by merging;

IF BM <= BM_rank_20 			   	THEN BMGroup=1;
IF BM_rank_20<BM <= BM_rank_40 		THEN BMGroup=2;
IF BM_rank_40<BM < =BM_rank_60 		THEN BMGroup=3;
IF BM_rank_60<BM < =BM_rank_80 		THEN BMGroup=4;
IF BM_rank_80< BM 					THEN BMGroup=5;

Drop  fyear  bm_rank_20 bm_rank_40  bm_rank_60 bm_rank_80;

run;

* --------------------------------------------------------------------*
*** 3. Read in Fama and French 3 factors
* --------------------------------------------------------------------*;

filename tempdir 'C:\RESEARCH\Macro-Finance\CovCharicteristic\Data\F-F_Research_Data_Factors_Monthly.csv';

data FF3factors;
informat date yymmn6.;
format date yymmn6.;
  infile tempdir firstobs=2 dlm=',' missover;
  input date mkt smb hml rf;
  year=year(date);
  month=month(date);
   mkt=mkt/100;
  smb=smb/100;
  hml=hml/100;
  rf=rf/100;
  yyyymm=year*100 + month; 
run;
proc sort data= FF3factors; by date;run;


*************************************************
* data cleaning
*************************************************;
Data BM;
set crspCompuMergedNew;

	if bm = . or bm = .S or bm = .C or bm=.A or bm= .M or bm=.I or bm=.B or bm=.E then delete;
	if June_me = . or June_me = .S or June_me = .C or June_me=.A or June_me= .M or June_me=.I or June_me=.B or June_me=.E then delete;
	if Dec_me = . or Dec_me = .S or Dec_me = .C or Dec_me=.A or Dec_me= .M or Dec_me=.I or Dec_me=.B or Dec_me=.E then delete;
	if Ret = . or Ret = .S or Ret = .C or Ret=.A or Ret= .M or Ret=.I or Ret=.B or Ret=.E then delete;	
run;
proc sort data=BM; by NPERMNO year month;run;

* --------------------------------------------------------------------*
4.	Get rolling HML beta
* --------------------------------------------------------------------*;

/*************************************************
 * macros to run ff_4factor regressions
 ************************************************/

/* 
 * ff4f regression
 * this macro runs a regression of monthly returns on carhart 4 factors
 * 
 * params: dataset, var
 * var: could be a list of variables
 */
%macro ff4f(dsetin, dsetout, sortby, no_fac, min);
proc sql;
	create table mret1 as
	select a.*, a.ret - b.rf as xret, b.mkt, b.smb, b.hml
	from &dsetin as a, FF3factors as b
	where a.year = b.year and a.month = b.month;
quit;
proc sort data = mret1;
	by &sortby year month;
run;
proc reg data = mret1 outest = beta noprint tableout;
	by &sortby;
%if &no_fac = 1 %then %do;
	model xret = mkt /rsquare;
%end;
%else %if &no_fac = 3 %then %do;
	model xret = mkt smb hml/rsquare;
%end;
%else %if &no_fac = 4 %then %do;
	model xret = mktrf smb hml umd/rsquare;
%end;
run;
data beta1;
	set beta;
	if _TYPE_ = 'PARMS' or _TYPE_ = 'T';
run;
data beta2;
	set beta1;
	if _TYPE_ = 'PARMS';
run;
data &dsetout (drop = drop = _model_ _type_ _model_ _depvar_ _rmse_ xret _in_ _p_);
	set beta2;
	if _EDF_ + 4 >= &min;
run;
%mend ff4f;
/* 
 * rolling ff4f regression
 * this macro runs a rolling regression of monthly returns on Carhart 4 factors
 */
* %let in = s12_10;
* %let out = fundalpha;
* backward = 0: from t+1 to t+len;
* backward = 1, from t-len+1 to t;
%macro rolling_ff4f(dsetin, dsetout, var, no_fac, len, min, backward);
%if &backward = 1 %then %do;
proc sql;
	create table rolling as
	select a.&var, a.year as _year, a.month as _month, b.year, b.month, b.ret
	from &dsetin as a, &dsetin as b
	where a.&var = b.&var and
	      0 <= a.year * 12 + a.month - (b.year * 12 + b.month) < &len;
quit;
%end;
%else %do;
proc sql;
	create table rolling as
	select a.&var, a.year as _year, a.month as _month, b.year, b.month, b.ret
	from &dsetin as a, &dsetin as b
	where a.&var = b.&var and
	      0 < b.year * 12 + b.month - (a.year * 12 + a.month) <= &len;
quit;
%end;

proc sort data = rolling;
	by &var _year _month year month;
run;

%ff4f(rolling, rolling1, &var _year _month, &no_fac, &min);

data &dsetout (rename = (_year = year _month = month));
	set rolling1;
run;
%mend rolling_ff4f;

%rolling_ff4f(BM, Rolling1,NPERMNO,3,36,36,1)

*************************************************;
data rollingBeta;
set Rolling1;
where month = 12;
cyear = year;
keep NPERMNO cyear HML;
run;

proc sort data=rollingBeta;by npermno cyear;run;
proc sort data=BM;by Npermno cyear;run;

* merge BM and rollingBeta;
data BMRollingBeta;
merge BM(in=in1) RollingBeta(in=in2);
	by Npermno cyear;
run;

data BMRollingBeta;
set BMRollingBeta;
	if HML = . then delete;
	if BM  = . then delete;
	run;

* --------------------------------------------------------------------*
* 5. Double sort first on BM, second on HML beta;
* --------------------------------------------------------------------*;
*proc sort data=BMRollingBeta; *by NPERMNO Cyear month ;*run;
proc sort data=BMRollingBeta; by BMgroup Cyear HML ;run;

*// Within BM (NYSE breakpoints) portfolio, sort on HML beta to create equal number of firms in each portfolio;
	proc rank data=BMRollingBeta out=group2 groups=5; by BMgroup Cyear; var HML; ranks HMLgroup;run;
*// to get average returns and other characteristics of each portfolios; 
	proc sort data=group2; by BMgroup HMLgroup yyyymm; run;
proc means noprint data=group2; 
	var ret bm june_me ; by BMgroup HMLgroup yyyymm; 
			WEIGHT lagme; output out=port1monthly 
			mean= ret bm june_me; run;
data port1monthly;
set port1monthly;
	if HMLgroup = . then delete;
	if BMgroup = . then delete;run;
*proc sort;*by _freq_;*run;
	Data port1monthly;set port1monthly; 
	ret=ret; drop _freq_ _type_  ;run;
	proc sort data=port1monthly; by BMgroup HMLgroup;
	proc means noprint data=port1monthly; by BMgroup HMLgroup;
		var ret  bm june_me ;
		output out=port1monthlyMeans 
		mean = ret bm june_me;run;
	proc print data=port1monthlymeans;run;

*******************************************;
* Get average excess returns;
********************************************;
data port1monthly1;
set port1monthly;
keep BMgroup HMLgroup yyyymm ret;
BMgroup = BMgroup;
HMLgroup = HMLgroup + 1;
run;
data port1monthly1;
set port1monthly1;
Index = BMgroup*10 + HMLgroup;
drop HMLgroup BMgroup ;
run;
proc sort data=port1monthly1; by yyyymm index; run;
proc transpose data=port1monthly1 out= port1monthlyTrans;
by yyyymm;
id Index;
run;
data port1monthlyTrans;set port1monthlyTrans;drop _name_ _label_ year month;run;
	
*// Merge FF3 factors with the portfolio returns;
proc sort data=port1monthlyTrans; by yyyymm;run;

data port1monthlyTransMerged;
merge port1monthlyTrans FF3factors;
by yyyymm;
where 201007>yyyymm>197306;
run;


********************************************
** 5 by 5 portfolio excess returns
**********************************************;
data port1monthlyTransMerged;
set port1monthlyTransMerged;
r11 = 100*(_11 -rf); r12 = 100*(_12 -rf);r13 = 100*(_13 -rf); r14 = 100*(_14 -rf); r15 = 100*(_15 -rf); 
r21 = 100*(_21 -rf); r22 = 100*(_22 -rf);r23 = 100*(_23 -rf); r24 = 100*(_24 -rf); r25 = 100*(_25 -rf);  
r31 = 100*(_31 -rf); r32 = 100*(_32 -rf);r33 = 100*(_33 -rf); r34 = 100*(_34 -rf); r35 = 100*(_35 -rf); 
r41 = 100*(_41 -rf); r42 = 100*(_42 -rf);r43 = 100*(_43 -rf); r44 = 100*(_44 -rf); r45 = 100*(_45 -rf);  
r51 = 100*(_51 -rf); r52 = 100*(_52 -rf);r53 = 100*(_53 -rf); r54 = 100*(_54 -rf); r55 = 100*(_55 -rf); 

drop _11 _12 _13 _14 _15 _21 _22 _23 _24 _25 _31 _32 _33 _34 _35 _41 _42 _43 _44 _45 _51 _52 _53 _54 _55 ;
run;

** param contains the average excess returns of 25 HML loading and BM portfolio returns;
proc means noprint data=port1monthlyTransMerged; 
		var r11 r12 r13 r14 r15 r21 r22 r23 r24 r25 r31 r32 r33 r34 r35 r41 r42 r43 r44 r45 r51 r52 r53 r54 r55;
		output out=param 
		mean = r11 r12 r13 r14 r15 r21 r22 r23 r24 r25 r31 r32 r33 r34 r35 r41 r42 r43 r44 r45 r51 r52 r53 r54 r55;run;

* --------------------------------------------------------------------*
* 6. Double sort first on HML beta, second on BM 
* --------------------------------------------------------------------*;
proc sort data=BMRollingBeta; by Cyear HML BMgroup ;run;
* // First, sort on HML beta, then sort on BM portfolio//;
proc rank data=BMRollingBeta out=group1 groups=5; by Cyear ; var HML; ranks HMLgroup; run;

*// Within HML portfolio, use BM as the sorting variable;
	proc sort data=group1; by HMLgroup Cyear; run;
	proc rank data=group1 out=group3 groups=5; by HMLgroup Cyear; var BM; ranks BMgroup;run;
*// to get average returns and other characteristics of each portfolios; 
	proc sort data=group3; by BMgroup HMLgroup yyyymm; run;
proc means noprint data=group3; 
	var ret bm june_me ; by BMgroup HMLgroup yyyymm; 
			WEIGHT lagme; output out=port1monthly 
			mean= ret bm june_me; run;
data port1monthly;
set port1monthly;
	if HMLgroup = . then delete;
	if BMgroup = . then delete;run;
	Data port1monthly;set port1monthly; 
	ret=ret; drop _freq_ _type_  ;run;
	proc sort data=port1monthly; by BMgroup HMLgroup;
	proc means noprint data=port1monthly; by BMgroup HMLgroup;
		var ret  bm june_me ;
		output out=port1monthlyMeans 
		mean = ret bm june_me;run;
	proc print data=port1monthlymeans;run;

*******************************************;
* Get average excess returns;
********************************************;
data port1monthly1;
set port1monthly;
keep BMgroup HMLgroup yyyymm ret;
BMgroup = BMgroup + 1;
HMLgroup = HMLgroup + 1;
run;
data port1monthly1;
set port1monthly1;
Index = BMgroup*10 + HMLgroup;
drop HMLgroup BMgroup ;
run;
proc sort data=port1monthly1; by yyyymm index; run;
proc transpose data=port1monthly1 out= port1monthlyTrans;
by yyyymm;
id Index;
run;
data port1monthlyTrans;set port1monthlyTrans;drop _name_ _label_ year month;run;
*// Merge FF3 factors with the portfolio returns;
proc sort data=port1monthlyTrans; by yyyymm;run;

data port1monthlyTransMerged;
merge port1monthlyTrans FF3factors;
by yyyymm;
where 201007>yyyymm>197306;
run;


********************************************
** 5 by 5 portfolio excess returns
**********************************************;
data port1monthlyTransMerged;
set port1monthlyTransMerged;
r11 = 100*(_11 -rf); r12 = 100*(_12 -rf);r13 = 100*(_13 -rf); r14 = 100*(_14 -rf); r15 = 100*(_15 -rf); 
r21 = 100*(_21 -rf); r22 = 100*(_22 -rf);r23 = 100*(_23 -rf); r24 = 100*(_24 -rf); r25 = 100*(_25 -rf);  
r31 = 100*(_31 -rf); r32 = 100*(_32 -rf);r33 = 100*(_33 -rf); r34 = 100*(_34 -rf); r35 = 100*(_35 -rf); 
r41 = 100*(_41 -rf); r42 = 100*(_42 -rf);r43 = 100*(_43 -rf); r44 = 100*(_44 -rf); r45 = 100*(_45 -rf);  
r51 = 100*(_51 -rf); r52 = 100*(_52 -rf);r53 = 100*(_53 -rf); r54 = 100*(_54 -rf); r55 = 100*(_55 -rf); 

drop _11 _12 _13 _14 _15 _21 _22 _23 _24 _25 _31 _32 _33 _34 _35 _41 _42 _43 _44 _45 _51 _52 _53 _54 _55 ;
run;

** param2 contains the average excess returns of 25 HML loading and BM portfolio returns;
proc means noprint data=port1monthlyTransMerged; 
		var r11 r12 r13 r14 r15 r21 r22 r23 r24 r25 r31 r32 r33 r34 r35 r41 r42 r43 r44 r45 r51 r52 r53 r54 r55;
		output out=param2
		mean = r11 r12 r13 r14 r15 r21 r22 r23 r24 r25 r31 r32 r33 r34 r35 r41 r42 r43 r44 r45 r51 r52 r53 r54 r55;run;

